<?php

namespace B2buy\Tutorial\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use B2buy\Tutorial\Interfaces\TutorialRepositoryInterface;

class TutorialPublicController extends BaseController
{
    // use TutorialWorkflow;

    /**
     * Constructor.
     *
     * @param type \B2buy\Tutorial\Interfaces\TutorialRepositoryInterface $tutorial
     *
     * @return type
     */
    public function __construct(TutorialRepositoryInterface $tutorial)
    {
        $this->repository = $tutorial;
        parent::__construct();
    }

    /**
     * Show tutorial's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $tutorials = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('tutorial::tutorial.names'))
            ->view('tutorial::public.tutorial.index')
            ->data(compact('tutorials'))
            ->output();
    }


    /**
     * Show tutorial.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $tutorial = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($tutorial->name . trans('tutorial::tutorial.name'))
            ->view('tutorial::public.tutorial.show')
            ->data(compact('tutorial'))
            ->output();
    }

}
