<?php

namespace B2buy\Tutorial\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use B2buy\Tutorial\Http\Requests\TutorialcategoryRequest;
use B2buy\Tutorial\Interfaces\TutorialcategoryRepositoryInterface;
use B2buy\Tutorial\Models\Tutorialcategory;

/**
 * Resource controller class for tutorialcategory.
 */
class TutorialcategoryResourceController extends BaseController
{

    /**
     * Initialize tutorialcategory resource controller.
     *
     * @param type TutorialcategoryRepositoryInterface $tutorialcategory
     *
     * @return null
     */
    public function __construct(TutorialcategoryRepositoryInterface $tutorialcategory)
    {
        parent::__construct();
        $this->repository = $tutorialcategory;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Tutorial\Repositories\Criteria\TutorialcategoryResourceCriteria::class);
    }

    /**
     * Display a list of tutorialcategory.
     *
     * @return Response
     */
    public function index(TutorialcategoryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\B2buy\Tutorial\Repositories\Presenter\TutorialcategoryPresenter::class)
                ->$function();
        }

        $tutorialcategories = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('tutorial::tutorialcategory.names'))
            ->view('tutorial::tutorialcategory.index', true)
            ->data(compact('tutorialcategories', 'view'))
            ->output();
    }

    /**
     * Display tutorialcategory.
     *
     * @param Request $request
     * @param Model   $tutorialcategory
     *
     * @return Response
     */
    public function show(TutorialcategoryRequest $request, Tutorialcategory $tutorialcategory)
    {

        if ($tutorialcategory->exists) {
            $view = 'tutorial::tutorialcategory.show';
        } else {
            $view = 'tutorial::tutorialcategory.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('tutorial::tutorialcategory.name'))
            ->data(compact('tutorialcategory'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new tutorialcategory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TutorialcategoryRequest $request)
    {

        $tutorialcategory = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('tutorial::tutorialcategory.name')) 
            ->view('tutorial::tutorialcategory.create', true) 
            ->data(compact('tutorialcategory'))
            ->output();
    }

    /**
     * Create new tutorialcategory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TutorialcategoryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $tutorialcategory                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('tutorial::tutorialcategory.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('tutorial/tutorialcategory/' . $tutorialcategory->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/tutorial/tutorialcategory'))
                ->redirect();
        }

    }

    /**
     * Show tutorialcategory for editing.
     *
     * @param Request $request
     * @param Model   $tutorialcategory
     *
     * @return Response
     */
    public function edit(TutorialcategoryRequest $request, Tutorialcategory $tutorialcategory)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('tutorial::tutorialcategory.name'))
            ->view('tutorial::tutorialcategory.edit', true)
            ->data(compact('tutorialcategory'))
            ->output();
    }

    /**
     * Update the tutorialcategory.
     *
     * @param Request $request
     * @param Model   $tutorialcategory
     *
     * @return Response
     */
    public function update(TutorialcategoryRequest $request, Tutorialcategory $tutorialcategory)
    {
        try {
            $attributes = $request->all();

            $tutorialcategory->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('tutorial::tutorialcategory.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('tutorial/tutorialcategory/' . $tutorialcategory->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('tutorial/tutorialcategory/' . $tutorialcategory->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the tutorialcategory.
     *
     * @param Model   $tutorialcategory
     *
     * @return Response
     */
    public function destroy(TutorialcategoryRequest $request, Tutorialcategory $tutorialcategory)
    {
        try {

            $tutorialcategory->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('tutorial::tutorialcategory.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('tutorial/tutorialcategory/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('tutorial/tutorialcategory/' . $tutorialcategory->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple tutorialcategory.
     *
     * @param Model   $tutorialcategory
     *
     * @return Response
     */
    public function delete(TutorialcategoryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('tutorial::tutorialcategory.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('tutorial/tutorialcategory'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/tutorial/tutorialcategory'))
                ->redirect();
        }

    }

    /**
     * Restore deleted tutorialcategories.
     *
     * @param Model   $tutorialcategory
     *
     * @return Response
     */
    public function restore(TutorialcategoryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('tutorial::tutorialcategory.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/tutorial/tutorialcategory'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/tutorial/tutorialcategory/'))
                ->redirect();
        }

    }

}
