<?php

namespace B2buy\Tutorial\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Tutorial\Http\Requests\TutorialtagRequest;
use B2buy\Tutorial\Interfaces\TutorialtagRepositoryInterface;
use B2buy\Tutorial\Models\Tutorialtag;
use B2buy\Tutorial\Forms\Tutorialtag as Form;

/**
 * APIController  class for tutorialtag.
 */
class TutorialtagAPIController extends BaseController
{

    /**
     * Initialize tutorialtag resource controller.
     *
     * @param type TutorialtagRepositoryInterface $tutorialtag
     *
     * @return null
     */
    public function __construct(TutorialtagRepositoryInterface $tutorialtag)
    {
        parent::__construct();
        $this->repository = $tutorialtag;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Tutorial\Repositories\Criteria\TutorialtagResourceCriteria::class);
    }

    /**
     * Display a list of tutorialtag.
     *
     * @return Response
     */
    public function index(TutorialtagRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Tutorial\Repositories\Presenter\TutorialtagPresenter::class)
            ->paginate();
    }

    /**
     * Display tutorialtag.
     *
     * @param Request $request
     * @param Model   $tutorialtag
     *
     * @return Response
     */
    public function show(TutorialtagRequest $request, Tutorialtag $tutorialtag)
    {
        return $tutorialtag->setPresenter(\B2buy\Tutorial\Repositories\Presenter\TutorialtagListPresenter::class);
        ;
    }

    /**
     * Create new tutorialtag.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TutorialtagRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('tutorial::tutorialtag.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('tutorial/tutorialtag/' . $tutorialtag->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('tutorial/tutorialtag');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the tutorialtag.
     *
     * @param Request $request
     * @param Model   $tutorialtag
     *
     * @return Response
     */
    public function update(TutorialtagRequest $request, Tutorialtag $tutorialtag)
    {
        try {
            $data = $request->all();

            $tutorialtag->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('tutorial::tutorialtag.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('tutorial/tutorialtag/' . $tutorialtag->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('tutorial/tutorialtag/' . $tutorialtag->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the tutorialtag.
     *
     * @param Model   $tutorialtag
     *
     * @return Response
     */
    public function destroy(TutorialtagRequest $request, Tutorialtag $tutorialtag)
    {
        try {
            $tutorialtag->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('tutorial::tutorialtag.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('tutorial/tutorialtag/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('tutorial/tutorialtag/' . $tutorialtag->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
