<?php

namespace B2buy\Tutorial\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\Tutorial\Http\Requests\TutorialtagRequest;
use B2buy\Tutorial\Models\Tutorialtag;

/**
 * Admin web controller class.
 */
class TutorialtagWorkflowController extends BaseController
{

    /**
     * Workflow controller function for tutorialtag.
     *
     * @param Model   $tutorialtag
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TutorialtagRequest $request, Tutorialtag $tutorialtag, $step)
    {

        try {

            $tutorialtag->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('tutorial::tutorialtag.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/tutorialtag/tutorialtag/' . $tutorialtag->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/tutorialtag/tutorialtag/' . $tutorialtag->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for tutorialtag.
     *
     * @param Model   $tutorialtag
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Tutorialtag $tutorialtag, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $tutorialtag->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('tutorial::tutorialtag.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tutorial::admin.tutorialtag.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tutorial::admin.tutorialtag.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tutorial::admin.tutorialtag.message', $data)->render();

        }

    }
}
