<?php

namespace B2buy\Tutorial\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Tutorial\Models\Tutorial;

class TutorialPolicy
{

    /**
     * Determine if the given user can view the tutorial.
     *
     * @param UserPolicy $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tutorial $tutorial)
    {
        if ($user->canDo('tutorial.tutorial.view') && $user->isAdmin()) {
            return true;
        }

        return $tutorial->user_id == user_id() && $tutorial->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tutorial.
     *
     * @param UserPolicy $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('tutorial.tutorial.create');
    }

    /**
     * Determine if the given user can update the given tutorial.
     *
     * @param UserPolicy $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tutorial $tutorial)
    {
        if ($user->canDo('tutorial.tutorial.edit') && $user->isAdmin()) {
            return true;
        }

        return $tutorial->user_id == user_id() && $tutorial->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tutorial.
     *
     * @param UserPolicy $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tutorial $tutorial)
    {
        return $tutorial->user_id == user_id() && $tutorial->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tutorial.
     *
     * @param UserPolicy $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tutorial $tutorial)
    {
        if ($user->canDo('tutorial.tutorial.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tutorial.
     *
     * @param UserPolicy $user
     * @param Tutorial $tutorial
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tutorial $tutorial)
    {
        if ($user->canDo('tutorial.tutorial.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
