<?php

namespace B2buy\Tutorial\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Tutorial\Models\Tutorialcategory;

class TutorialcategoryPolicy
{

    /**
     * Determine if the given user can view the tutorialcategory.
     *
     * @param UserPolicy $user
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tutorialcategory $tutorialcategory)
    {
        if ($user->canDo('tutorial.tutorialcategory.view') && $user->isAdmin()) {
            return true;
        }

        return $tutorialcategory->user_id == user_id() && $tutorialcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tutorialcategory.
     *
     * @param UserPolicy $user
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('tutorial.tutorialcategory.create');
    }

    /**
     * Determine if the given user can update the given tutorialcategory.
     *
     * @param UserPolicy $user
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tutorialcategory $tutorialcategory)
    {
        if ($user->canDo('tutorial.tutorialcategory.edit') && $user->isAdmin()) {
            return true;
        }

        return $tutorialcategory->user_id == user_id() && $tutorialcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tutorialcategory.
     *
     * @param UserPolicy $user
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tutorialcategory $tutorialcategory)
    {
        return $tutorialcategory->user_id == user_id() && $tutorialcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tutorialcategory.
     *
     * @param UserPolicy $user
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tutorialcategory $tutorialcategory)
    {
        if ($user->canDo('tutorial.tutorialcategory.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tutorialcategory.
     *
     * @param UserPolicy $user
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tutorialcategory $tutorialcategory)
    {
        if ($user->canDo('tutorial.tutorialcategory.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
