<?php

namespace B2buy\Tutorial\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Tutorial\Models\Tutorialtag;

class TutorialtagPolicy
{

    /**
     * Determine if the given user can view the tutorialtag.
     *
     * @param UserPolicy $user
     * @param Tutorialtag $tutorialtag
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tutorialtag $tutorialtag)
    {
        if ($user->canDo('tutorial.tutorialtag.view') && $user->isAdmin()) {
            return true;
        }

        return $tutorialtag->user_id == user_id() && $tutorialtag->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tutorialtag.
     *
     * @param UserPolicy $user
     * @param Tutorialtag $tutorialtag
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('tutorial.tutorialtag.create');
    }

    /**
     * Determine if the given user can update the given tutorialtag.
     *
     * @param UserPolicy $user
     * @param Tutorialtag $tutorialtag
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tutorialtag $tutorialtag)
    {
        if ($user->canDo('tutorial.tutorialtag.edit') && $user->isAdmin()) {
            return true;
        }

        return $tutorialtag->user_id == user_id() && $tutorialtag->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tutorialtag.
     *
     * @param UserPolicy $user
     * @param Tutorialtag $tutorialtag
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tutorialtag $tutorialtag)
    {
        return $tutorialtag->user_id == user_id() && $tutorialtag->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tutorialtag.
     *
     * @param UserPolicy $user
     * @param Tutorialtag $tutorialtag
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tutorialtag $tutorialtag)
    {
        if ($user->canDo('tutorial.tutorialtag.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tutorialtag.
     *
     * @param UserPolicy $user
     * @param Tutorialtag $tutorialtag
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tutorialtag $tutorialtag)
    {
        if ($user->canDo('tutorial.tutorialtag.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
