<?php

namespace B2buy\Tutorial\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\Tutorial\Models\Tutorial;

class TutorialAction
{
    /**
     * Perform the complete action.
     *
     * @param Tutorial $tutorial
     *
     * @return Tutorial
     */
    public function complete(Tutorial $tutorial)
    {
        try {
            $tutorial->status = 'complete';
            return $tutorial->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Tutorial $tutorial
     *
     * @return Tutorial
     */public function verify(Tutorial $tutorial)
    {
        try {
            $tutorial->status = 'verify';
            return $tutorial->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Tutorial $tutorial
     *
     * @return Tutorial
     */public function approve(Tutorial $tutorial)
    {
        try {
            $tutorial->status = 'approve';
            return $tutorial->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Tutorial $tutorial
     *
     * @return Tutorial
     */public function publish(Tutorial $tutorial)
    {
        try {
            $tutorial->status = 'publish';
            return $tutorial->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Tutorial $tutorial
     *
     * @return Tutorial
     */
    public function archive(Tutorial $tutorial)
    {
        try {
            $tutorial->status = 'archive';
            return $tutorial->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Tutorial $tutorial
     *
     * @return Tutorial
     */
    public function unpublish(Tutorial $tutorial)
    {
        try {
            $tutorial->status = 'unpublish';
            return $tutorial->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
