<?php

namespace B2buy\Tutorial\Workflow;

use B2buy\Tutorial\Models\Tutorialcategory;
use Validator;

class TutorialcategoryValidator
{

    /**
     * Determine if the given tutorialcategory is valid for complete status.
     *
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool / Validator
     */
    public function complete(Tutorialcategory $tutorialcategory)
    {
        return Validator::make($tutorialcategory->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given tutorialcategory is valid for verify status.
     *
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool / Validator
     */
    public function verify(Tutorialcategory $tutorialcategory)
    {
        return Validator::make($tutorialcategory->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given tutorialcategory is valid for approve status.
     *
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool / Validator
     */
    public function approve(Tutorialcategory $tutorialcategory)
    {
        return Validator::make($tutorialcategory->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given tutorialcategory is valid for publish status.
     *
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool / Validator
     */
    public function publish(Tutorialcategory $tutorialcategory)
    {
        return Validator::make($tutorialcategory->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given tutorialcategory is valid for archive status.
     *
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool / Validator
     */
    public function archive(Tutorialcategory $tutorialcategory)
    {
        return Validator::make($tutorialcategory->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given tutorialcategory is valid for unpublish status.
     *
     * @param Tutorialcategory $tutorialcategory
     *
     * @return bool / Validator
     */
    public function unpublish(Tutorialcategory $tutorialcategory)
    {
        return Validator::make($tutorialcategory->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
