<?php

namespace B2buy\Tutorial\Workflow;

use B2buy\Tutorial\Models\Tutorialtag;
use Validator;

class TutorialtagValidator
{

    /**
     * Determine if the given tutorialtag is valid for complete status.
     *
     * @param Tutorialtag $tutorialtag
     *
     * @return bool / Validator
     */
    public function complete(Tutorialtag $tutorialtag)
    {
        return Validator::make($tutorialtag->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given tutorialtag is valid for verify status.
     *
     * @param Tutorialtag $tutorialtag
     *
     * @return bool / Validator
     */
    public function verify(Tutorialtag $tutorialtag)
    {
        return Validator::make($tutorialtag->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given tutorialtag is valid for approve status.
     *
     * @param Tutorialtag $tutorialtag
     *
     * @return bool / Validator
     */
    public function approve(Tutorialtag $tutorialtag)
    {
        return Validator::make($tutorialtag->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given tutorialtag is valid for publish status.
     *
     * @param Tutorialtag $tutorialtag
     *
     * @return bool / Validator
     */
    public function publish(Tutorialtag $tutorialtag)
    {
        return Validator::make($tutorialtag->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given tutorialtag is valid for archive status.
     *
     * @param Tutorialtag $tutorialtag
     *
     * @return bool / Validator
     */
    public function archive(Tutorialtag $tutorialtag)
    {
        return Validator::make($tutorialtag->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given tutorialtag is valid for unpublish status.
     *
     * @param Tutorialtag $tutorialtag
     *
     * @return bool / Validator
     */
    public function unpublish(Tutorialtag $tutorialtag)
    {
        return Validator::make($tutorialtag->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
